@@ -275,6 +275,8 @@ parse_sloppiness(const std::string& value)
       result |= SLOPPY_LOCALE;
     } else if (token == "modules") {
       result |= SLOPPY_MODULES;
+    } else if (token == "ivfsoverlay") {
+      result |= SLOPPY_IVFSOVERLAY;
     } // else: ignore unknown value for forward compatibility
     start = value.find_first_not_of(", ", end);
   }
@@ -315,6 +317,9 @@ format_sloppiness(uint32_t sloppiness)
   if (sloppiness & SLOPPY_MODULES) {
     result += "modules, ";
   }
+  if (sloppiness & SLOPPY_IVFSOVERLAY) {
+    result += "ivfsoverlay, ";
+  }
   if (!result.empty()) {
     // Strip last ", ".
     result.resize(result.size() - 2);
