@@ -232,6 +232,15 @@ process_arg(Context& ctx,
     return nullopt;
   }
 
+  // Ignore clang -ivfsoverlay <arg> to not detect multiple input files.
+  if (args[i] == "-ivfsoverlay"
+      && !(config.sloppiness() & SLOPPY_IVFSOVERLAY)) {
+    LOG_RAW(
+      "You have to specify \"ivfsoverlay\" sloppiness when using"
+      " -ivfsoverlay to get hits");
+    return Statistic::unsupported_compiler_option;
+  }
+
   // Special case for -E.
   if (args[i] == "-E") {
     return Statistic::called_for_preprocessing;
@@ -618,13 +627,19 @@ process_arg(Context& ctx,
     return nullopt;
   }
 
+  if (args[i] == "-P" || args[i] == "-Wp,-P") {
+    // Avoid passing -P to the preprocessor since it removes preprocessor
+    // information we need.
+    state.compiler_only_args.push_back(args[i]);
+    LOG("{} used; not compiling preprocessed code", args[i]);
+    config.set_run_second_cpp(true);
+    return nullopt;
+  }
+
   if (Util::starts_with(args[i], "-Wp,")) {
-    if (args[i] == "-Wp,-P" || args[i].find(",-P,") != std::string::npos
+    if (args[i].find(",-P,") != std::string::npos
         || Util::ends_with(args[i], ",-P")) {
-      // -P removes preprocessor information in such a way that the object file
-      // from compiling the preprocessed file will not be equal to the object
-      // file produced when compiling without ccache.
-      LOG_RAW("Too hard option -Wp,-P detected");
+      // -P together with other preprocessor options is just too hard.
       return Statistic::unsupported_compiler_option;
     } else if (Util::starts_with(args[i], "-Wp,-MD,")
                && args[i].find(',', 8) == std::string::npos) {
@@ -1107,7 +1122,14 @@ process_args(Context& ctx)
   }
 
   if (args_info.seen_split_dwarf) {
-    args_info.output_dwo = Util::change_extension(args_info.output_obj, ".dwo");
+    if (args_info.output_obj == "/dev/null") {
+      // Outputting to /dev/null -> compiler won't write a .dwo, so just pretend
+      // we haven't seen the -gsplit-dwarf option.
+      args_info.seen_split_dwarf = false;
+    } else {
+      args_info.output_dwo =
+        Util::change_extension(args_info.output_obj, ".dwo");
+    }
   }
 
   // Cope with -o /dev/null.
